@@ -673,7 +673,12 @@ void KNewFileMenuPrivate::executeRealFileOrDir(const KNewFileMenuSingleton::Entr
 
 void KNewFileMenuPrivate::executeSymLink(const KNewFileMenuSingleton::Entry &entry)
 {
-    KNameAndUrlInputDialog *dlg = new KNameAndUrlInputDialog(i18n("Name for new link:"), entry.comment, m_popupFiles.first(), m_parentWidget);
+    auto targetUrl = m_popupFiles.first();
+    if (!targetUrl.isLocalFile()) {
+        targetUrl = mostLocalUrl(targetUrl);
+    }
+
+    KNameAndUrlInputDialog *dlg = new KNameAndUrlInputDialog(i18n("Name for new link:"), entry.comment, targetUrl, m_parentWidget);
     dlg->setModal(q->isModal());
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setWindowTitle(i18n("Create Symlink"));
@@ -914,7 +919,8 @@ QUrl KNewFileMenuPrivate::mostLocalUrl(const QUrl &url)
 
 void KNewFileMenuPrivate::slotAbortDialog()
 {
-    m_text = QString();
+    m_text.clear();
+
     if (m_creatingDirectory) {
         Q_EMIT q->directoryCreationRejected(m_baseUrl);
     } else {
@@ -1006,12 +1012,11 @@ void KNewFileMenuPrivate::slotCreateDirectory()
     job->uiDelegate()->setAutoErrorHandlingEnabled(true);
     KJobWidgets::setWindow(job, m_parentWidget);
 
-    if (job) {
-        // We want the error handling to be done by slotResult so that subclasses can reimplement it
-        job->uiDelegate()->setAutoErrorHandlingEnabled(false);
-        QObject::connect(job, &KJob::result, q, &KNewFileMenu::slotResult);
-    }
-    slotAbortDialog();
+    // We want the error handling to be done by slotResult so that subclasses can reimplement it
+    job->uiDelegate()->setAutoErrorHandlingEnabled(false);
+    QObject::connect(job, &KJob::result, q, &KNewFileMenu::slotResult);
+
+    m_text.clear();
 }
 
 static QStringList getInstalledTemplates()
@@ -1180,7 +1185,7 @@ void KNewFileMenuPrivate::slotRealFileOrDir()
         m_text.chop(1);
     }
     m_copyData.m_chosenFileName = m_text;
-    slotAbortDialog();
+    m_text.clear();
     executeStrategy();
 }
 
@@ -1253,11 +1258,15 @@ void KNewFileMenuPrivate::_k_slotTextChanged(const QString &text)
             if (folders.count() > 1) {
                 label = i18n("Using slashes in folder names will create sub-folders, like so:");
                 QString indentation = QString();
+                int i = 0;
                 for (const QString &folder : std::as_const(folders)) {
                     label.append(QLatin1Char('\n'));
                     label.append(indentation);
                     label.append(folder);
-                    label.append(QStringLiteral("/"));
+                    i++;
+                    if (folders.count() != i) {
+                        label.append(QStringLiteral("/"));
+                    }
                     indentation.append(QStringLiteral("    "));
                 }
             } else {
