@@ -164,7 +164,7 @@ private:
     CachePolicy canBeCached(const QString &path);
     int getDeviceId(const QString &path);
     void saveThumbnailData(QImage &thumb);
-    void preparePluginForMimetype(const QString &mimeType);
+    bool preparePluginForMimetype(const QString &mimeType);
     static void saveThumbnailToCache(const QImage &thumb, const QString &path);
 };
 
