@@ -112,8 +112,9 @@ QUrl protocolChangedToHttp(const QUrl &url)
     // Keeps the 's' at the end, if present.
     protocol.replace(QLatin1String{"webdav"}, QLatin1String{"http"});
     protocol.replace(QLatin1String{"dav"}, QLatin1String{"http"});
-    if (newUrl.scheme() != protocol)
+    if (newUrl.scheme() != protocol) {
         newUrl.setScheme(protocol);
+    }
     return newUrl;
 }
 };
@@ -151,7 +152,7 @@ void HTTPProtocol::handleSslErrors(QNetworkReply *reply, const QList<QSslError>
 
     const QList<QSslError> fatalErrors = KSslCertificateManager::nonIgnorableErrors(sslErrors);
     if (!fatalErrors.isEmpty()) {
-        qCWarning(KIOHTTP_LOG) << "SSL errors that cannot be ignored occured" << fatalErrors;
+        qCWarning(KIOHTTP_LOG) << "SSL errors that cannot be ignored occurred" << fatalErrors;
         Q_EMIT errorOut(KIO::ERR_CANNOT_CONNECT);
         return;
     }
@@ -460,7 +461,35 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
         inputData->startTransaction(); // To be able to restart after redirects.
     }
 
-    QNetworkReply *reply = nam.sendCustomRequest(request, methodToString(method), inputData);
+    // sendCustomRequest(..., "FOO") behaves differently from dedicated foo().
+    // This sometimes causes requests to get stuck, when e.g. head() knows it shouldn't
+    // expect content but custom("HEAD") keeps waiting until the connection times out.
+    // Therefore, use the proper method, if possible.
+    // This has been addressed in Qt 6.11, see https://codereview.qt-project.org/c/qt/qtbase/+/666393
+    QNetworkReply *reply = nullptr;
+    switch (method) {
+    case KIO::HTTP_GET:
+        reply = nam.get(request, inputData);
+        break;
+    case KIO::HTTP_PUT:
+        reply = nam.put(request, inputData);
+        break;
+    case KIO::HTTP_POST:
+        reply = nam.post(request, inputData);
+        break;
+    case KIO::HTTP_HEAD:
+        reply = nam.head(request);
+        break;
+    case KIO::HTTP_DELETE:
+        reply = nam.deleteResource(request);
+        break;
+    default:
+        reply = nam.sendCustomRequest(request, methodToString(method), inputData);
+    }
+
+    const auto replyDeleter = qScopeGuard([reply] {
+        reply->deleteLater();
+    });
 
     bool mimeTypeEmitted = false;
 
@@ -492,7 +521,18 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
 
         if (statusCode >= 300 && statusCode < 400) {
             const QString redir = reply->attribute(QNetworkRequest::RedirectionTargetAttribute).toString();
-            const QUrl newUrl = url.resolved(QUrl(redir));
+            QUrl newUrl = url.resolved(QUrl(redir));
+
+            // Restore the old protocol (http, webdav or dav) after the redirection, but with the correct encryption status
+            bool upgradeToSecure = !url.scheme().endsWith(QLatin1Char('s')) && newUrl.scheme().endsWith(QLatin1Char('s'));
+            bool downgradeToInsecure = url.scheme().endsWith(QLatin1Char('s')) && !newUrl.scheme().endsWith(QLatin1Char('s'));
+            if (upgradeToSecure) {
+                newUrl.setScheme(url.scheme() + QLatin1Char('s'));
+            } else if (downgradeToInsecure) {
+                newUrl.setScheme(url.scheme().chopped(1));
+            } else {
+                newUrl.setScheme(url.scheme());
+            }
 
             // Handled after returning from the event loop.
             // 301 is necessary for Apache (see bugs 209508 and 187970).
@@ -566,7 +606,6 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
         }
         QUrl newUrl = url;
         newUrl.setPath(newUrl.path() + QLatin1Char('/'));
-        reply->deleteLater();
         return makeRequest(newUrl, method, inputData, dataMode, extraHeaders);
     }
     if (inputData) {
@@ -583,8 +622,6 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
 
     const int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
     if (reply->error() != QNetworkReply::NoError && statusCode == 0) {
-        reply->deleteLater();
-
         // anything not listed here gets KIO::ERR_CANNOT_CONNECT
         static constexpr const std::pair<QNetworkReply::NetworkError, int> qnam2kio_errors[] = {
             {QNetworkReply::HostNotFoundError, KIO::ERR_UNKNOWN_HOST},
@@ -605,7 +642,6 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
         return {0, QByteArray(), it != std::end(qnam2kio_errors) ? (*it).second : KIO::ERR_CANNOT_CONNECT};
     }
     if (reply->error() == QNetworkReply::AuthenticationRequiredError) {
-        reply->deleteLater();
         return {0, QByteArray(), KIO::ERR_ACCESS_DENIED};
     }
 
@@ -629,8 +665,6 @@ HTTPProtocol::Response HTTPProtocol::makeRequest(const QUrl &url,
     setMetaData(QStringLiteral("responsecode"), QString::number(statusCode));
     setMetaData(QStringLiteral("content-type"), readMimeType(reply));
 
-    reply->deleteLater();
-
     return {statusCode, returnData};
 }
 
@@ -798,13 +832,10 @@ KIO::WorkerResult HTTPProtocol::davStatList(const QUrl &url, bool stat)
 
     Response response = makeDavRequest(url, method, inputData, DataMode::Return, extraHeaders);
 
-    // Has a redirection already been called? If so, we're done.
-    // if (m_isRedirection || m_kioError) {
-    // if (m_isRedirection) {
-    // return davFinished();
-    // }
-    // return WorkerResult::pass();
-    // }
+    // If this is a redirection we don't have anything to do
+    if (response.httpCode >= 300 && response.httpCode < 400) {
+        return KIO::WorkerResult::pass();
+    }
 
     QDomDocument multiResponse;
     multiResponse.setContent(response.data, QDomDocument::ParseOption::UseNamespaceProcessing);
